=== modified file 'drizzled/sql_delete.cc'
--- drizzled/sql_delete.cc	2009-10-03 00:45:59 +0000
+++ drizzled/sql_delete.cc	2009-10-07 21:45:49 +0000
@@ -460,7 +460,7 @@
         TRUNCATE must always be statement-based binlogged (not row-based) so
         we don't test current_stmt_binlog_row_based.
       */
-      write_bin_log(session, true, session->query, session->query_length);
+      write_bin_log(session, session->query, session->query_length);
       session->my_ok();		// This should return record count
     }
     pthread_mutex_lock(&LOCK_open); /* For truncate delete from hash when finished */

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2009-10-03 00:45:59 +0000
+++ drizzled/sql_table.cc	2009-10-07 21:45:49 +0000
@@ -314,7 +314,6 @@
   SYNOPSIS
     write_bin_log()
     session                           Thread object
-    clear_error                   is clear_error to be called
     query                         Query to log
     query_length                  Length of query
 
@@ -326,7 +325,7 @@
     file
 */
 
-void write_bin_log(Session *session, bool,
+void write_bin_log(Session *session,
                    char const *query, size_t query_length)
 {
   ReplicationServices &replication_services= ReplicationServices::singleton();
@@ -334,6 +333,30 @@
 }
 
 
+/* Should should be refactored to go away */
+static void write_bin_log_drop_table(Session *session, bool if_exists, const char *db_name, const char *table_name)
+{
+  ReplicationServices &replication_services= ReplicationServices::singleton();
+  string built_query;
+
+  if (if_exists)
+    built_query.append("DROP Table IF EXISTS ");
+  else
+    built_query.append("DROP Table ");
+
+  built_query.append("`");
+  if (session->db == NULL || strcmp(db_name ,session->db) != 0)
+  {
+    built_query.append(db_name);
+    built_query.append("`.`");
+  }
+
+  built_query.append(table_name);
+  built_query.append("`");
+  replication_services.rawStatement(session, built_query.c_str(), built_query.length());
+}
+
+
 /*
  delete (drop) tables.
 
@@ -381,7 +404,7 @@
     LOCK_open during wait_if_global_read_lock(), other threads could not
     close their tables. This would make a pretty deadlock.
   */
-  error= mysql_rm_table_part2(session, tables, if_exists, drop_temporary, 0);
+  error= mysql_rm_table_part2(session, tables, if_exists, drop_temporary, false);
 
   if (need_start_waiting)
     start_waiting_global_read_lock(session);
@@ -402,7 +425,6 @@
     if_exists		If set, don't give an error if table doesn't exists.
 			In this case we give an warning of level 'NOTE'
     drop_temporary	Only drop temporary tables
-    drop_view		Allow to delete VIEW .frm
     dont_log_query	Don't write query to log files. This will also not
 			generate warnings if the handler files doesn't exists
 
@@ -430,18 +452,7 @@
   uint32_t path_length= 0;
   String wrong_tables;
   int error= 0;
-  int non_temp_tables_count= 0;
-  bool some_tables_deleted=0, tmp_table_deleted=0, foreign_key_error=0;
-  String built_query;
-
-  if (!dont_log_query)
-  {
-    built_query.set_charset(system_charset_info);
-    if (if_exists)
-      built_query.append("DROP Table IF EXISTS ");
-    else
-      built_query.append("DROP Table ");
-  }
+  bool foreign_key_error= false;
 
   pthread_mutex_lock(&LOCK_open); /* Part 2 of rm a table */
 
@@ -478,7 +489,6 @@
     switch (error) {
     case  0:
       // removed temporary table
-      tmp_table_deleted= 1;
       continue;
     case -1:
       error= 1;
@@ -488,30 +498,6 @@
       error= 0;
     }
 
-    /*
-      If row-based replication is used and the table is not a
-      temporary table, we add the table name to the drop statement
-      being built.  The string always end in a comma and the comma
-      will be chopped off before being written to the binary log.
-      */
-    if (!dont_log_query)
-    {
-      non_temp_tables_count++;
-      /*
-        Don't write the database name if it is the current one (or if
-        session->db is NULL).
-      */
-      built_query.append("`");
-      if (session->db == NULL || strcmp(db,session->db) != 0)
-      {
-        built_query.append(db);
-        built_query.append("`.`");
-      }
-
-      built_query.append(table->table_name);
-      built_query.append("`,");
-    }
-
     table_type= table->db_type;
     if (!drop_temporary)
     {
@@ -535,6 +521,7 @@
       /* remove .frm file and engine files */
       path_length= build_table_filename(path, sizeof(path), db, table->table_name, table->internal_tmp_table);
     }
+
     if (drop_temporary ||
         ((table_type == NULL
           && (plugin::StorageEngine::getTableProto(path, NULL) != EEXIST))))
@@ -552,22 +539,22 @@
       error= plugin::StorageEngine::deleteTable(session, path, db,
                                                 table->table_name,
                                                 ! dont_log_query);
-      if ((error == ENOENT || error == HA_ERR_NO_SUCH_TABLE) &&
-	  if_exists)
+      if ((error == ENOENT || error == HA_ERR_NO_SUCH_TABLE) && if_exists)
       {
 	error= 0;
         session->clear_error();
       }
+
       if (error == HA_ERR_ROW_IS_REFERENCED)
       {
         /* the table is referenced by a foreign key constraint */
-        foreign_key_error=1;
-      }
-      if (error == 0)
-      {
-          some_tables_deleted=1;
+        foreign_key_error= true;
       }
     }
+
+    if (error == 0 || (if_exists && foreign_key_error == false))
+        write_bin_log_drop_table(session, if_exists, db, table->table_name);
+
     if (error)
     {
       if (wrong_tables.length())
@@ -593,50 +580,6 @@
     error= 1;
   }
 
-  if (some_tables_deleted || tmp_table_deleted || !error)
-  {
-    if (!dont_log_query)
-    {
-      if ((non_temp_tables_count > 0 && !tmp_table_deleted))
-      {
-        /*
-          In this case, we are either using statement-based
-          replication or using row-based replication but have only
-          deleted one or more non-temporary tables (and no temporary
-          tables).  In this case, we can write the original query into
-          the binary log.
-         */
-        write_bin_log(session, !error, session->query, session->query_length);
-      }
-      else if (non_temp_tables_count > 0 &&
-               tmp_table_deleted)
-      {
-        /*
-          In this case we have deleted both temporary and
-          non-temporary tables, so:
-          - since we have deleted a non-temporary table we have to
-            binlog the statement, but
-          - since we have deleted a temporary table we cannot binlog
-            the statement (since the table has not been created on the
-            slave, this might cause the slave to stop).
-
-          Instead, we write a built statement, only containing the
-          non-temporary tables, to the binary log
-        */
-        built_query.chop();                  // Chop of the last comma
-        built_query.append(" /* generated by server */");
-        write_bin_log(session, !error, built_query.ptr(), built_query.length());
-      }
-      /*
-        The remaining cases are:
-        - no tables where deleted and
-        - only temporary tables where deleted and row-based
-          replication is used.
-        In both these cases, nothing should be written to the binary
-        log.
-      */
-    }
-  }
   pthread_mutex_lock(&LOCK_open); /* final bit in rm table lock */
 err_with_placeholders:
   unlock_table_names(tables, NULL);
@@ -1827,7 +1770,7 @@
    */
   if (!internal_tmp_table &&
       ((!(create_info->options & HA_LEX_CREATE_TMP_TABLE))))
-    write_bin_log(session, true, session->query, session->query_length);
+    write_bin_log(session, session->query, session->query_length);
   error= false;
 unlock_and_end:
   pthread_mutex_unlock(&LOCK_open);
@@ -2606,10 +2549,10 @@
         int result= store_create_info(table, &query, create_info);
 
         assert(result == 0); // store_create_info() always return 0
-        write_bin_log(session, true, query.ptr(), query.length());
+        write_bin_log(session, query.ptr(), query.length());
       }
       else                                      // Case 1
-        write_bin_log(session, true, session->query, session->query_length);
+        write_bin_log(session, session->query, session->query_length);
     }
   }
 

=== modified file 'drizzled/sql_table.h'
--- drizzled/sql_table.h	2009-09-23 19:20:45 +0000
+++ drizzled/sql_table.h	2009-10-07 21:45:49 +0000
@@ -59,7 +59,7 @@
 bool mysql_optimize_table(Session* session, TableList* table_list,
                           HA_CHECK_OPT* check_opt);
 
-void write_bin_log(Session *session, bool clear_error,
+void write_bin_log(Session *session,
                    char const *query, size_t query_length);
 
 bool is_primary_key(KEY *key_info);

=== modified file 'drizzled/statement/alter_table.cc'
--- drizzled/statement/alter_table.cc	2009-10-06 17:03:54 +0000
+++ drizzled/statement/alter_table.cc	2009-10-07 21:45:49 +0000
@@ -543,7 +543,7 @@
     error=1;
   if (error)
     goto err;
-  write_bin_log(session, false, session->query, session->query_length);
+  write_bin_log(session, session->query, session->query_length);
 
 err:
   ha_autocommit_or_rollback(session, error);
@@ -919,7 +919,7 @@
 
     if (error == 0)
     {
-      write_bin_log(session, true, session->query, session->query_length);
+      write_bin_log(session, session->query, session->query_length);
       session->my_ok();
     }
     else if (error > 0)
@@ -1129,7 +1129,7 @@
 
   session->set_proc_info("end");
 
-  write_bin_log(session, true, session->query, session->query_length);
+  write_bin_log(session, session->query, session->query_length);
 
   if (old_db_type->check_flag(HTON_BIT_FLUSH_AFTER_RENAME))
   {

=== modified file 'drizzled/statement/analyze.cc'
--- drizzled/statement/analyze.cc	2009-09-19 00:39:27 +0000
+++ drizzled/statement/analyze.cc	2009-10-07 21:45:49 +0000
@@ -33,7 +33,7 @@
   Select_Lex *select_lex= &session->lex->select_lex;
   bool res= mysql_analyze_table(session, first_table, &check_opt);
   /* ! we write after unlocking the table */
-  write_bin_log(session, true, session->query, session->query_length);
+  write_bin_log(session, session->query, session->query_length);
   select_lex->table_list.first= (unsigned char*) first_table;
   session->lex->query_tables= all_tables;
   return res;

=== modified file 'drizzled/statement/flush.cc'
--- drizzled/statement/flush.cc	2009-10-01 17:21:30 +0000
+++ drizzled/statement/flush.cc	2009-10-07 21:45:49 +0000
@@ -40,7 +40,7 @@
      *
      * Presumably, RESET and binlog writing doesn't require synchronization
      */
-    write_bin_log(session, false, session->query, session->query_length);
+    write_bin_log(session, session->query, session->query_length);
     session->my_ok();
   }
 

=== modified file 'drizzled/statement/optimize.cc'
--- drizzled/statement/optimize.cc	2009-09-19 00:39:27 +0000
+++ drizzled/statement/optimize.cc	2009-10-07 21:45:49 +0000
@@ -33,7 +33,7 @@
   Select_Lex *select_lex= &session->lex->select_lex;
   bool res= mysql_optimize_table(session, first_table, &check_opt);
   /* ! we write after unlocking the table */
-  write_bin_log(session, true, session->query, session->query_length);
+  write_bin_log(session, session->query, session->query_length);
   select_lex->table_list.first= (unsigned char*) first_table;
   session->lex->query_tables= all_tables;
   return res;

=== modified file 'drizzled/statement/rename_table.cc'
--- drizzled/statement/rename_table.cc	2009-09-29 22:27:05 +0000
+++ drizzled/statement/rename_table.cc	2009-10-07 21:45:49 +0000
@@ -107,7 +107,7 @@
   /* Lets hope this doesn't fail as the result will be messy */
   if (! error)
   {
-    write_bin_log(session, true, session->query, session->query_length);
+    write_bin_log(session, session->query, session->query_length);
     session->my_ok();
   }
 

=== modified file 'tests/suite/command_log/r/alter.result'
--- tests/suite/command_log/r/alter.result	2009-09-24 21:58:19 +0000
+++ tests/suite/command_log/r/alter.result	2009-10-07 21:45:49 +0000
@@ -8,7 +8,7 @@
 INSERT INTO t1 VALUES (2, "I hate testing.");
 ALTER TABLE t1 ADD dummy INT;
 /*  */
-DROP TABLE IF EXISTS t1;
+DROP Table IF EXISTS `t1`;
 /*  */
 CREATE TABLE t1 ( id INT NOT NULL , padding VARCHAR(200) NOT NULL , PRIMARY KEY (id) );
 /*  */

=== modified file 'tests/suite/command_log/r/delete.result'
--- tests/suite/command_log/r/delete.result	2009-09-24 21:58:19 +0000
+++ tests/suite/command_log/r/delete.result	2009-10-07 21:45:49 +0000
@@ -8,7 +8,7 @@
 INSERT INTO t1 VALUES (2, "I hate testing.");
 DELETE FROM t1 where id = 1;
 /*  */
-DROP TABLE IF EXISTS t1;
+DROP Table IF EXISTS `t1`;
 /*  */
 CREATE TABLE t1 ( id INT NOT NULL , padding VARCHAR(200) NOT NULL , PRIMARY KEY (id) );
 /*  */

=== modified file 'tests/suite/command_log/r/filtered_replicator.result'
--- tests/suite/command_log/r/filtered_replicator.result	2009-09-24 21:58:19 +0000
+++ tests/suite/command_log/r/filtered_replicator.result	2009-10-07 21:45:49 +0000
@@ -63,31 +63,33 @@
 UPDATE t1 SET padding= "XXX" WHERE id= 1;
 UPDATE t1 SET padding= "AAA";
 /*  */
-DROP TABLE IF EXISTS t1;
-/*  */
-CREATE TABLE t1 ( id INT NOT NULL , padding VARCHAR(200) NOT NULL );
-/*  */
-INSERT INTO `test`.`t1` (`id`,`padding`) VALUES ('1','I love testing.');
-/*  */
-INSERT INTO `test`.`t1` (`id`,`padding`) VALUES ('2','I hate testing.');
-/*  */
-DROP TABLE IF EXISTS t1;
-/*  */
-CREATE TABLE t1 ( id INT NOT NULL , padding VARCHAR(200) NOT NULL );
-/*  */
-INSERT INTO `test`.`t1` (`id`,`padding`) VALUES ('1','I love testing.');
-/*  */
-INSERT INTO `test`.`t1` (`id`,`padding`) VALUES ('2','I hate testing.');
-/*  */
-DROP TABLE IF EXISTS t1;
-/*  */
-CREATE TABLE t1 ( id INT NOT NULL , padding VARCHAR(200) NOT NULL );
-/*  */
-INSERT INTO `test`.`t1` (`id`,`padding`) VALUES ('1','I love testing.');
-/*  */
-INSERT INTO `test`.`t1` (`id`,`padding`) VALUES ('2','I hate testing.');
-/*  */
-DROP TABLE IF EXISTS t1;
+DROP Table IF EXISTS `t1`;
+/*  */
+CREATE TABLE t1 ( id INT NOT NULL , padding VARCHAR(200) NOT NULL );
+/*  */
+INSERT INTO `test`.`t1` (`id`,`padding`) VALUES ('1','I love testing.');
+/*  */
+INSERT INTO `test`.`t1` (`id`,`padding`) VALUES ('2','I hate testing.');
+/*  */
+DROP Table IF EXISTS `t1`;
+/*  */
+CREATE TABLE t1 ( id INT NOT NULL , padding VARCHAR(200) NOT NULL );
+/*  */
+INSERT INTO `test`.`t1` (`id`,`padding`) VALUES ('1','I love testing.');
+/*  */
+INSERT INTO `test`.`t1` (`id`,`padding`) VALUES ('2','I hate testing.');
+/*  */
+DROP Table IF EXISTS `t1`;
+/*  */
+DROP Table IF EXISTS `t2`;
+/*  */
+CREATE TABLE t1 ( id INT NOT NULL , padding VARCHAR(200) NOT NULL );
+/*  */
+INSERT INTO `test`.`t1` (`id`,`padding`) VALUES ('1','I love testing.');
+/*  */
+INSERT INTO `test`.`t1` (`id`,`padding`) VALUES ('2','I hate testing.');
+/*  */
+DROP Table IF EXISTS `t1`;
 /*  */
 CREATE TABLE t1 ( id INT NOT NULL , padding VARCHAR(200) NOT NULL , PRIMARY KEY (id) );
 /*  */
@@ -101,13 +103,15 @@
 /*  */
 DROP DATABASE test1;
 /*  */
-DROP TABLE IF EXISTS t1, t2;
+DROP Table IF EXISTS `t1`;
+/*  */
+DROP Table IF EXISTS `t2`;
 /*  */
 CREATE TABLE t1 ( id INT NOT NULL , padding VARCHAR(200) NOT NULL , PRIMARY KEY (id) );
 /*  */
 RENAME TABLE t1 TO t2;
 /*  */
-DROP TABLE IF EXISTS t1;
+DROP Table IF EXISTS `t1`;
 /*  */
 CREATE TABLE t1 ( id INT NOT NULL , padding VARCHAR(200) NOT NULL , PRIMARY KEY (id) );
 /*  */
@@ -117,7 +121,7 @@
 /*  */
 DELETE FROM `test`.`t1` WHERE `id` = '1';
 /*  */
-DROP TABLE IF EXISTS t1;
+DROP Table IF EXISTS `t1`;
 /*  */
 CREATE TABLE t1 ( id INT NOT NULL , padding VARCHAR(200) NOT NULL , PRIMARY KEY (id) );
 /*  */

=== modified file 'tests/suite/command_log/r/insert.result'
--- tests/suite/command_log/r/insert.result	2009-09-24 21:58:19 +0000
+++ tests/suite/command_log/r/insert.result	2009-10-07 21:45:49 +0000
@@ -6,7 +6,7 @@
 INSERT INTO t1 VALUES (1, "I love testing.");
 INSERT INTO t1 VALUES (2, "I hate testing.");
 /*  */
-DROP TABLE IF EXISTS t1;
+DROP Table IF EXISTS `t1`;
 /*  */
 CREATE TABLE t1 ( id INT NOT NULL , padding VARCHAR(200) NOT NULL );
 /*  */

=== modified file 'tests/suite/command_log/r/insert_multi.result'
--- tests/suite/command_log/r/insert_multi.result	2009-09-24 21:58:19 +0000
+++ tests/suite/command_log/r/insert_multi.result	2009-10-07 21:45:49 +0000
@@ -5,7 +5,7 @@
 );
 INSERT INTO t1 VALUES (1, "I love testing."), (2, "I hate testing.");
 /*  */
-DROP TABLE IF EXISTS t1;
+DROP Table IF EXISTS `t1`;
 /*  */
 CREATE TABLE t1 ( id INT NOT NULL , padding VARCHAR(200) NOT NULL );
 /*  */

=== modified file 'tests/suite/command_log/r/insert_select.result'
--- tests/suite/command_log/r/insert_select.result	2009-09-24 21:58:19 +0000
+++ tests/suite/command_log/r/insert_select.result	2009-10-07 21:45:49 +0000
@@ -12,9 +12,9 @@
 );
 INSERT INTO t2 SELECT * FROM t1;
 /*  */
-DROP TABLE IF EXISTS t1;
+DROP Table IF EXISTS `t1`;
 /*  */
-DROP TABLE IF EXISTS t2;
+DROP Table IF EXISTS `t2`;
 /*  */
 CREATE TABLE t1 ( id INT NOT NULL , padding VARCHAR(200) NOT NULL );
 /*  */

=== modified file 'tests/suite/command_log/r/rename.result'
--- tests/suite/command_log/r/rename.result	2009-07-29 23:25:20 +0000
+++ tests/suite/command_log/r/rename.result	2009-10-07 21:45:49 +0000
@@ -6,7 +6,9 @@
 );
 RENAME TABLE t1 TO t2;
 /*  */
-DROP TABLE IF EXISTS t1, t2;
+DROP Table IF EXISTS `t1`;
+/*  */
+DROP Table IF EXISTS `t2`;
 /*  */
 CREATE TABLE t1 ( id INT NOT NULL , padding VARCHAR(200) NOT NULL , PRIMARY KEY (id) );
 /*  */

=== modified file 'tests/suite/command_log/r/update.result'
--- tests/suite/command_log/r/update.result	2009-09-24 21:58:19 +0000
+++ tests/suite/command_log/r/update.result	2009-10-07 21:45:49 +0000
@@ -9,7 +9,7 @@
 UPDATE t1 SET padding= "XXX" WHERE id= 1;
 UPDATE t1 SET padding= "AAA";
 /*  */
-DROP TABLE IF EXISTS t1;
+DROP Table IF EXISTS `t1`;
 /*  */
 CREATE TABLE t1 ( id INT NOT NULL , padding VARCHAR(200) NOT NULL , PRIMARY KEY (id) );
 /*  */

